@@ -25,6 +25,11 @@ ROOT_DIR = os.path.dirname(os.path.realpath(__file__))
 _CFG_ROOT_DIR = 'ROOT_DIR'
 def set_root_dir(root_dir):
     root_dir = root_dir.strip()
+    if root_dir[0] == '~' and root_dir[1] in r'\/':
+        root_dir[:1] = Path.home()
+    assert os.path.isabs(root_dir), 'ERROR: Only absolute path is allowed'
+    if not os.path.exists(root_dir):
+        os.makedirs(root_dir, DIR_ACCESS_RIGHTS)
     cfg_path = os.path.join(str(Path.home()), '.rumor')
     cfg = ["# Config file for RuMor project. Don't change it manually."]
     isdone = False
@@ -51,15 +56,22 @@ def set_root_dir(root_dir):
 def get_root_dir():
     cfg_path = os.path.join(str(Path.home()), '.rumor')
     res = ROOT_DIR
-    with open(cfg_path, 'rt', encoding='utf-8') as f:
-        for line in f:
-            try:
-                var, val = line.split('\t', maxsplit=1)
-                if var == _CFG_ROOT_DIR:
-                    res = val.strip()
-                    break
-            except ValueError:
-                pass
+    try:
+        with open(cfg_path, 'rt', encoding='utf-8') as f:
+            for line in f:
+                try:
+                    var, val = line.split('\t', maxsplit=1)
+                    if var == _CFG_ROOT_DIR:
+                        res = val.strip()
+                        break
+                except ValueError:
+                    pass
+    except FileNotFoundError:
+        raise FileNotFoundError(
+           'Configuration file is absent. Invoke '
+           '`corpuscula.corpus_utils.set_root_dir(<directory where to '
+           'create corpora storage>)` to create it'
+        )
     return res
 
 CORPUS_DNAME = 'corpus'
@@ -183,20 +195,23 @@ def download_ud(corpus_name, root_dir=None, overwrite=True):
             dpath = os.path.join(dpath, corpus_name)
             if train:
                 fpaths.append(
-                    download_corpus('{}/{}:train'.format(UD, corpus_name),
-                                    train, dname=dpath, root_dir='',
-                                    overwrite=overwrite))
+                    download_file(train, dpath=dpath, overwrite=overwrite,
+                                  log_msg='Downloading {}/{}:train'
+                                              .format(UD, corpus_name))
+                )
             if dev:
                 fpaths.append(
-                    download_corpus('{}/{}:dev'.format(UD, corpus_name),
-                                    dev, dname=dpath, root_dir='',
-                                    overwrite=overwrite))
+                    download_file(dev, dpath=dpath, overwrite=overwrite,
+                                  log_msg='Downloading {}/{}:dev'
+                                              .format(UD, corpus_name))
+                )
             if test:
                 fpaths.append(
-                    download_corpus('{}/{}:test'.format(UD, corpus_name),
-                                    test, dname=dpath, root_dir='',
-                                    overwrite=overwrite))
-        os.remove(fcont)
+                    download_file(test, dpath=dpath, overwrite=overwrite,
+                                  log_msg='Downloading {}/{}:test'
+                                              .format(UD, corpus_name))
+                )
+        #os.remove(fcont)
     return fpaths
 
 def remove_ud(corpus_name, root_dir=None):
